@@ -53,5 +53,5 @@ class ElectroOpticalExtension(BaseModel):
 
     class Config:
         use_enum_values = True
-        allow_population_by_fieldname = True
+        allow_population_by_field_name = True
         alias_generator = lambda field_name: f"eo:{field_name}"
