@@ -56,5 +56,5 @@ class PointCloudExtension(BaseModel):
 
     class Config:
         use_enum_values = True
-        allow_population_by_fieldname = True
+        allow_population_by_field_name = True
         alias_generator = lambda field_name: f"pc:{field_name}"
