@@ -30,4 +30,4 @@ class SatelliteExtension(BaseModel):
 
     class Config:
         use_enum_values = True
-        allow_population_by_fieldname = True
+        allow_population_by_field_name = True
